<?php
/**
 * Class for Wow Plugin Update
 *
 * @package     Wow_Plugin
 * @copyright   Copyright (c) 2018., Dmytro Lobov
 * @license     http://opensource.org/licenses/gpl-2.0.php GNU Public License
 * @since       1.0
 *
 */

namespace side_menu_pro;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Wow_Plugin_Update_Class {

	private $arg;

	public function __construct( $arg ) {
    $this->plugin_name = $arg[ 'plugin_name' ];
    $this->plugin_version = $arg[ 'plugin_version' ];
    $this->author = $arg[ 'author' ];
    $this->plugin_file = $arg[ 'plugin_file' ];
    $this->plugin_pref = $arg[ 'plugin_pref' ];
    $this->plugin_slug = $arg[ 'plugin_slug' ];
    $this->author_url = $arg[ 'author_url' ];
    $this->text_domain = $arg[ 'text_domain' ];
    $this->plugin_dir = $arg[ 'plugin_dir' ];

		add_filter( $this->plugin_slug . '_tab_menu', array( $this, 'filter_tab_menu') );
		add_filter( $this->plugin_slug . '_menu_file', array( $this, 'filter_menu_file') );

		// update plugin
		add_action( 'admin_init', array( $this, 'plugin_updater' ), 0 );
		// check plugin
		add_action( 'admin_init', array( $this, 'register_option' ) );
		add_action( 'admin_init', array( $this, 'activate_license' ) );
		add_action( 'admin_init', array( $this, 'deactivate_license' ) );
		add_action( 'admin_notices', array( $this, 'admin_notices' ) );

    register_deactivation_hook( $this->plugin_dir . $this->plugin_file , array( $this, 'deactivate_plugin' ) );
	}

	public function filter_tab_menu( $menu ){
		if( $menu['extension'] ) {
			unset($menu['extension']);
		}
		if(empty($menu['license'])){
			$menu['license'] = __( 'License', $this->text_domain );
		}
		return $menu;
	}

	public function filter_menu_file( $tab ) {
		$license = get_option( 'wow_license_key_' . $this->plugin_pref );
		$status = get_option( 'wow_license_status_' . $this->plugin_pref );
		if ($tab === 'list' || $tab === 'add_new') {
			if( empty($license) || $status !== 'valid') {
				$tab = plugin_dir_path( __FILE__ ) . 'updater/license';
			}
		}
		elseif($tab === 'license') {
			$tab = plugin_dir_path( __FILE__ ) . 'updater/license';
		}
		return $tab;
	}

	// Update plugin
	public function plugin_updater() {
		require_once plugin_dir_path( __FILE__ ) . 'updater/class-update.php';
		$license_key = trim( get_option( 'wow_license_key_' . $this->plugin_pref ) );
		$updater     = __NAMESPACE__ . '\\WOW_PLUGIN_UPDATE';
		$edd_updater = new WOW_PLUGIN_UPDATE( $this->author_url, $this->plugin_file, array(
				'version'   => $this->plugin_version,
				'license'   => $license_key,
				'item_name' => $this->plugin_name,
				'author'    => $this->author,
				'url'       => home_url()
			)
		);
	}

	// Check plugin
	public function register_option() {
		register_setting( 'wow_license_' . $this->plugin_pref, 'wow_license_key_' . $this->plugin_pref,
			array( $this, 'sanitize_license' ) );
	}

	public function sanitize_license( $new ) {
		$old = get_option( 'wow_license_key_' . $this->plugin_pref );
		if ( $old && $old != $new ) {
			delete_option( 'wow_license_status_' . $this->plugin_pref );
		}

		return $new;
	}

	public function activate_license() {
		require_once plugin_dir_path( __FILE__ ) . 'updater/activate.php';
	}

	public function deactivate_license() {
		require_once plugin_dir_path( __FILE__ ) . 'updater/deactivate.php';
	}

	public function admin_notices() {
		require_once plugin_dir_path( __FILE__ ) . 'updater/notices.php';
	}

	public function deactivate_plugin() {
    $license = trim( get_option( 'wow_license_key_' . $this->plugin_pref ) );
    $api_params = array(
      'edd_action'=> 'deactivate_license',
      'license' 	=> $license,
      'item_name' => urlencode( $this->plugin_name ),
      'url'       => home_url()
    );
    $response = wp_remote_post( $this->author_url, array( 'timeout' => 15, 'sslverify' => false, 'body' => $api_params ) );
    // decode the license data
    $license_data = json_decode( wp_remote_retrieve_body( $response ) );
    // $license_data->license will be either "deactivated" or "failed"
    if( $license_data->license == 'deactivated' ) {
      delete_option( 'wow_license_status_' . $this->plugin_pref );
    }
  }
}